/* -----------------------------------------
  scripts.js for esp-01 0.15
  part of Arduino Mega Server project
-------------------------------------------- */

// Date & time

function month(mon) {
  switch (mon) {
    case "1": return "января"; break;
    case "2": return "февраля"; break;
    case "3": return "марта"; break;
    case "4": return "апреля"; break;
    case "5": return "мая"; break;
    case "6": return "июня"; break;
    case "7": return "июля"; break;
    case "8": return "августа"; break;
    case "9": return "сентября"; break;
    case "10": return "октября"; break;
    case "11": return "ноября"; break;
    case "12": return "декабря"; break;
    default: return ""; break;
  }
}

function weekday(day) {
  switch (day) {
    case "1": return "Воскресенье"; break;
    case "2": return "Понедельник"; break;
    case "3": return "Вторник"; break;
    case "4": return "Среда"; break;
    case "5": return "Четверг"; break;
    case "6": return "Пятница"; break;
    case "7": return "Суббота"; break;
     default: return ""; break;
  }
}

// Network

function randomNoCache() {
  var random = Math.round(Math.random() * 10000);
  if (random < 10) {random *= 1000;}
  if (random < 100) {random *= 100;}
  if (random < 1000) {random *= 10;}
  return "&nocache=" + random;
}

// Data colors

var modulDisable = "#555555";
var modulPassive = "#887711";
var modulActive = "#1188dd";

function modulBackground     (state) {switch (state) {case "0": return modulPassive; break; case "1": return modulActive; break; default: return modulDisable; break;}}
function modulColor          (state) {switch (state) {case "0": return "#eeeeee"; break; case "1": return "#ffffff"; break; default: return "#aaaaaa"; break;}}

function modeBackground      (state) {switch (state) {case "1": return "#91A46B"; break; case "2": return "#AB5DB1"; break; default: return "#555555"; break;}}
function modeColor           (state) {switch (state) {case "1": return "#ffffff"; break; case "2": return "#ffffff"; break; default: return "#aaaaaa"; break;}}
function forceBackground     (state) {switch (state) {case "0": return "#6EA1D2"; break; case "1": return "#F4A509"; break; default: return "#555555"; break;}}
function forceColor          (state) {switch (state) {case "0": return "#ffffff"; break; case "1": return "#ffffff"; break; default: return "#aaaaaa"; break;}}
function authBackground      (state) {switch (state) {case "0": return "#03B882"; break; case "1": return "#DA7063"; break; default: return "#555555"; break;}}
function authColor           (state) {switch (state) {case "0": return "#ffffff"; break; case "1": return "#ffffff"; break; default: return "#aaaaaa"; break;}}
function megaBackground      (state) {switch (state) {case "0": return "#DA7063"; break; case "1": return "#04A9AE"; break; default: return "#555555"; break;}}
function megaColor           (state) {switch (state) {case "0": return "#ffffff"; break; case "1": return "#ffffff"; break; default: return "#aaaaaa"; break;}}

function onlineBackground    (state) {switch (state) {case "0": return "#555555"; break; case "1": return "#3EAF3B"; break; default: return "#555555"; break;}}
function onlineColor         (state) {switch (state) {case "0": return "#aaaaaa"; break; case "1": return "#ffffff"; break; default: return "#aaaaaa"; break;}}

function contactBackground   (state) {switch (state) {case "0": return "#68974C"; break; case "1": return "#B93737"; break; default: return "#555555"; break;}}
function contactColor        (state) {switch (state) {case "0": return "#eeeeee"; break; case "1": return "#ffffff"; break; default: return "#aaaaaa"; break;}}
function pirBackground       (state) {switch (state) {case "0": return "#09999E"; break; case "1": return "#eedd22"; break; default: return "#555555"; break;}}
function pirColor            (state) {switch (state) {case "0": return "#ffffff"; break; case "1": return "#555555"; break; default: return "#aaaaaa"; break;}}

function stateOnOffBackground(state) {switch (state) {case "0": return "#555555"; break; case "1": return "#FAF39B"; break; default: return "#555555"; break;}}
function stateOnOffColor     (state) {switch (state) {case "0": return "#ffffff"; break; case "1": return "#000000"; break; default: return "#aaaaaa"; break;}}
function stateOnOff          (state) {switch (state) {case "0": return "OFF";     break; case "1": return "ON";      break; default: return "-";       break;}}

/*
  Canvas graphics
-------------------------------------------- */

function maxInArray(buffer, maxBuff) {
  max = 0;
  for (var i = 0; i < maxBuff; i++) {
    if (buffer[i] > max) {
      max = buffer[i];
    }
  }
  return max;
}

function minInArray(buffer, maxBuff) {
  min = 1000000;
  for (var i = 0; i < maxBuff; i++) {
    if (buffer[i] < min) {
      min = buffer[i];
    }
  }
  return min;
}

function drawLine(x1, y1, x2, y2, width, color) {
  context.beginPath();
  context.moveTo(x1, y1);
  context.lineTo(x2, y2);
  context.moveTo(x2, y2);
  context.closePath();
  context.lineWidth = width;
  context.strokeStyle = color;
  context.stroke();
}

function drawXline(x1, x2, y, width, color) {
  context.beginPath();
  context.moveTo(x1, y);
  context.lineTo(x2, y);
  context.moveTo(x2, y);
  context.closePath();
  context.lineWidth = width;
  context.strokeStyle = color;
  context.stroke();
}

function drawYline(x, y1, y2, width, color) {
  context.beginPath();
  context.moveTo(x, y1);
  context.lineTo(x, y2);
  context.moveTo(x, y2);
  context.closePath();
  context.lineWidth = width;
  context.strokeStyle = color;
  context.stroke();
}

function drawXmarker(x, y1, y2, width, lineColor, marker, markerColor) {
  context.beginPath();
  context.moveTo(x, y1);
  context.lineTo(x, y2);
  context.moveTo(x, y2);
  context.closePath();
  context.lineWidth = width;
  context.strokeStyle = lineColor;
  context.stroke();
  context.fillStyle = markerColor;
  context.fillText(marker, x, y2 + 11, 50);
}

/*
  Function label()
    Draw label
--------------------------------- */

function label(value, place, measure, title, background) {
  title_font = '11px Tahoma';
  value_font = '18px Tahoma';
  color = 'white';

  elem = document.getElementById(place);
  context = elem.getContext('2d');

  context.fillStyle = background;
  context.fillRect(0, 0, elem.width, elem.height);

  context.fillStyle = color;
  context.fillRect(6, 33, 47, 1);

  context.textAlign = "center";

  context.font = value_font;
  context.fillText(value + measure, 30, 24, 55);

  context.font = title_font;
  context.fillText(title, 30, 49, 55);
} // label

function addTick(value, buffer, maxBuff, min) {
  for (var i = maxBuff - 1; i > 0; i--) {
    buffer[i] = buffer[i - 1];
  }
  buffer[0] = value;
  if (buffer[0] < min) {buffer[0] = min;}
}

function insertTick(value, buffer) {
  buffer[0] = value;
}

/*
  Function load()
    Draw load CPU graph
--------------------------------- */

function load(place, type, value1, value2, buffer1, buffer2, title, color, color1, color2) {
  var background = 'rgba(0, 0, 0, 1)';
  var title_font = '11px Tahoma';
  var value_font = '18px Tahoma';

  var step = 5;
  var shiftX = 33;
  var shiftY = 29;
  var kY = 5;

  // buffers works
  addTick(value1, buffer1, MAX_CPU_LOAD_BUFFER, kY);
  if (type == 2 || type == 4) {
    addTick(value2, buffer2, MAX_CPU_LOAD_BUFFER, kY);
  }

  // Context works
  element = document.getElementById(place);
  context = element.getContext('2d');

  context.fillStyle = background;
  context.fillRect(0, 0, element.width, element.height);

  // Graphics works
  for (var i = 0 ; i < MAX_CPU_LOAD_BUFFER; i++) {

    var i_protect = i;
    if (i >= MAX_CPU_LOAD_BUFFER - 1) {
      i_protect = i - 1;
    }

    switch (type) {
      case 2: // two bar graphics
        context.fillStyle = color1;
        context.fillRect(MAX_CPU_LOAD_BUFFER*step - i*step + shiftX,     shiftY, 2, -buffer1[i]/kY);
        context.fillStyle = color2;
        context.fillRect(MAX_CPU_LOAD_BUFFER*step - i*step + shiftX + 2, shiftY, 2, -buffer2[i]/kY);
        break;
      case 3: // one line graphics (two level graphics)
        context.lineWidth = 1;
        context.beginPath();
        context.moveTo(MAX_CPU_LOAD_BUFFER*step -             i*step + shiftX, shiftY - buffer1[i]/kY);
        context.lineTo(MAX_CPU_LOAD_BUFFER*step - (i_protect+1)*step + shiftX, shiftY - buffer1[i_protect+1]/kY);
        context.closePath();
        context.strokeStyle = color1;
        context.stroke();
        break;
      case 4: // two line graphics
        context.lineWidth = 1;
        context.beginPath();
        context.moveTo(MAX_CPU_LOAD_BUFFER*step -             i*step + shiftX, shiftY - buffer1[i]/kY);
        context.lineTo(MAX_CPU_LOAD_BUFFER*step - (i_protect+1)*step + shiftX, shiftY - buffer1[i_protect+1]/kY);
        context.closePath();
        context.strokeStyle = color1;
        context.stroke();

        context.beginPath();
        context.moveTo(MAX_CPU_LOAD_BUFFER*step -             i*step + shiftX, shiftY - buffer2[i]/kY);
        context.lineTo(MAX_CPU_LOAD_BUFFER*step - (i_protect+1)*step + shiftX, shiftY - buffer2[i_protect+1]/kY);
        context.closePath();
        context.strokeStyle = color2;
        context.stroke();
        break;
      default: // one (value1) bar graphics
        context.fillStyle = color;
        context.fillRect(MAX_CPU_LOAD_BUFFER*step - i*step + shiftX, shiftY, 4, -buffer1[i]/kY);
        break;
    } // switch (type)
  } // for (var i = 0 ; i < MAX_CPU_LOAD_BUFFER; i++)

  // Text works
  context.fillStyle = color;
  context.textAlign = "right";

  context.font = value_font;
  context.fillText(value1, 32, 17, 55);

  context.font = title_font;
  context.fillText(title, 32, 29, 55);
} // load

/* -----------------------
  Function line()
    Draw simple line graph
-------------------------- */

function line(place, value, buffer, color) {
  var step = 1;
  var shiftX = 20;
  var shiftY = 165;
  var kY = 1;

  // Y limit
  var maxBuff = maxInArray(buffer, MAX_GRAPH_BUFFER);
  var kVal = maxBuff / 100;
  if (maxBuff == 0) {
    kY = 0;
  }

  // Buffer works
  addTick(value, buffer, MAX_GRAPH_BUFFER, kY);

  // Context works
  element = document.getElementById(place);
  context = element.getContext('2d');
  context.clearRect(0, 0, element.width, element.height);

  // Graphics works
  for (var i = 0 ; i < MAX_GRAPH_BUFFER; i++) {
    var i_protect = i;
    if (i >= MAX_GRAPH_BUFFER - 1) {
      i_protect = i - 1;
    }
    context.lineWidth = 3;
    context.beginPath();
    context.moveTo(MAX_GRAPH_BUFFER*step -             i*step + shiftX, shiftY - (buffer[i]/kVal)/kY);
    context.lineTo(MAX_GRAPH_BUFFER*step - (i_protect+1)*step + shiftX, shiftY - (buffer[i_protect+1]/kVal)/kY);
    context.closePath();
    context.strokeStyle = color;
    context.stroke();
  } // i < MAX_GRAPH_BUFFER
} // line

/* ------------------------------
  Graphics Logo Works

--------------------------------- */

var shiftX = 20;
var shiftY = 10;
var lenX = 136;
var lenY = 136;
var logoColor = 'rgba(120, 170, 220, 1)';
var logoColorLight = 'rgba(50, 110, 150, 1)';
var width = 1;

function drawBorder(x, y, lenX, lenY, color) {
  var cor = 2;
  drawXline(x - cor, x + lenX + cor, y - 1,        1, color);
  drawXline(x - cor, x + lenX + cor, y + lenY + 1, 1, color);
  drawYline(x - 1,        y - cor, y + lenY + cor, 1, color);
  drawYline(x + lenX + 1, y - cor, y + lenY + cor, 1, color);
}

function clearLogo(place) {
  // context works
  try {
    element = document.getElementById(place);
    context = element.getContext('2d');
  } catch (err) {
      return;
    }

  // clear background
  context.fillStyle = 'black';
  context.fillRect(0, 0, element.width, element.height);

  // draw border
  drawBorder(shiftX, shiftY, lenX, lenY, logoColor);
}

/* ------------------------------
  Ping-Pong logo [1]

--------------------------------- */

function drawPong(place, x, y, color) {
  // context works
  try {
    element = document.getElementById(place);
    context = element.getContext('2d');
  } catch (err) {
      return;
    }
  
  // clear background
  context.fillStyle = 'black';
  context.fillRect(0, 0, element.width, element.height);

  // draw Pong
  context.fillStyle = color;
  context.arc(shiftX + x, shiftY + y, 6, 0, Math.PI * 2);
  context.fill();
  context.beginPath();
  context.fill();

  // draw border
  drawBorder(shiftX, shiftY, lenX, lenY, logoColor);
} // drawPong( )

var pongDim = 6;
var pongMinX = 0 + pongDim;
var pongMinY = 0 + pongDim;
var pongMaxX = 136 - pongDim;
var pongMaxY = 136 - pongDim;
var dX = 1;
var dY = 1;
var pongX = 7;
var pongY = 25;

function logoPong() {
  var pongColor = logoColor;

  if (pongX < pongMinX || pongX > pongMaxX) {dX = -dX;}
  if (pongY < pongMinY || pongY > pongMaxY) {dY = -dY;}
  if (pongY == 100) {pongY += dY * 2;}

  pongX += dX;
  pongY += dY;

  drawPong('logo', pongX, pongY, pongColor);
}

/* ------------------------------
  Radar logo [2]

--------------------------------- */

function drawRadar(place, liferPos, width, color) {
  var halfX = lenX / 2;
  var halfY = lenY / 2;
  liferPos = 34 - liferPos;

  // context works
  try {
    element = document.getElementById(place);
    context = element.getContext('2d');
  } catch (err) {
      return;
    }
  
  // draw radar
  context.lineWidth = width;
  context.beginPath();
  context.moveTo(shiftX, shiftY + (lenY - liferPos * 4));
  context.lineTo(shiftX + halfX, shiftY + halfX);
  context.lineTo(shiftX + (lenX - liferPos * 4), shiftY + lenY);
  context.moveTo(shiftX + (lenX - liferPos * 4), shiftY + lenY);
  context.moveTo(shiftX + (lenX - liferPos * 4), shiftY);
  context.lineTo(shiftX + halfX, shiftY + halfX);
  context.lineTo(shiftX + lenX, shiftY + (lenY - liferPos * 4));
  context.moveTo(shiftX + lenX, shiftY + (lenY - liferPos * 4));
  context.closePath();
  context.strokeStyle = color;
  context.stroke();

  // draw border
  drawBorder(shiftX, shiftY, lenX, lenY, logoColorLight);
} // drawRadar( )

var liferLogo = 0;
var phase = 1;
var radarColor = logoColor;

function logoRadar() {
  liferLogo++;
  if (liferLogo > 34) {liferLogo = 0;}

  if (liferLogo == 0) {
    phase = -phase;
    if (phase == 1) {
      radarColor = logoColor;
      width = 1;
    } else {
        radarColor = 'black';
        width = 2;
      }
  }
  // draw
  drawRadar('logo', liferLogo, width, radarColor);
}

/* ------------------------------
  Random Rects logo [3]

--------------------------------- */

function drawRect(place, x, y, color) {
  var step = 12;
  var shift = 3;
  var dim = 10;

  // context works
  try {
    element = document.getElementById(place);
    context = element.getContext('2d');
  } catch (err) {
      return;
    }
  
  // draw rect
  context.fillStyle = color;
  context.fillRect(shiftX + x*step + shift, shiftY + y*step + shift, dim, dim);
  context.fill();
  context.beginPath();
  context.fill();

  // draw border
  drawBorder(shiftX, shiftY, lenX, lenY, logoColorLight);
}

function logoRandomRects() {
  var show = 'rgba(100, 120, 200, 0.7)';
  var hide ='rgba(0, 0, 0, 1)';

  // random position
  var x = Math.round(Math.random() * 10);
  var y = Math.round(Math.random() * 10);

  // random color
  var colorRnd = Math.round(Math.random() * 1000);
  if (colorRnd > 500) {
    var color = show;
  } else {
      var color = hide;
    }

  // anomal colors
  if (colorRnd == 60) {color = 'rgba(40, 218, 34, 1)';} // green
  if (colorRnd == 70) {color = 'rgba(228, 185, 34, 1)';} // yellow
  if (colorRnd == 80) {color = 'rgba(218, 50, 34, 1)';} // red

  // draw
  drawRect('logo', x, y, color);
}

/* ------------------------------
  Function logoRotator()
    Show graphics logo
--------------------------------- */

var curLogo = 0;
var maxLogo = 3;
var logo1timer;
var logo2timer;
var logo3timer;
var netActivtimer;

function logoRotator() {
  // network act
  clearInterval(netActivtimer);
  netActivtimer = setInterval('netLoad()', 1000);
  
  // random logo
  if (curLogo == 0) { // start
    var logoRnd = Math.round(Math.random() * 10);
    curLogo = 1;
    if (logoRnd > 0 && logoRnd <= 3) {curLogo = 1;}
    if (logoRnd > 3 && logoRnd <= 6) {curLogo = 2;}
    if (logoRnd > 6 && logoRnd <= 10) {curLogo = 3;}
  } else { // cycle
      curLogo++;
    }

  if (curLogo > maxLogo) {curLogo = 1;}

  // clear timers
  clearInterval(logo1timer);
  clearInterval(logo2timer);
  clearInterval(logo3timer);

  // show current logo
  switch (curLogo) {
    case 1:
      logo1timer = setInterval('logoPong()', 20);
      break;
    case 2:
      clearLogo('logo');
      logo2timer = setInterval('logoRadar()', 80);
      break;
    case 3:
      clearLogo('logo');
      logo3timer = setInterval('logoRandomRects()', 120);
      break;
    default:
      break;
    } // switch (type)

  // change logo (period 1 minute)
  setTimeout('logoRotator()', 60000);
} // logoRotator()

function rndNumber() {
  var random = Math.round(Math.random() * 100000);
  if (random < 10) {random *= 1000;}
  if (random < 100) {random *= 100;}
  if (random < 1000) {random *= 10;}
  return random;
}

function genNumber() {
  try {
    var magicNumber = rndNumber();
    document.getElementById("magic-number").innerHTML = magicNumber;
  } catch (err) { }
}


/* -----------------------------------------
  dash.js
  part of Arduino Mega Server project
  Dashboard functions
-------------------------------------------- */

var currentPage = '';

// Var's for Processing sketch
var dash_marker1 = 0; // ok XML func
var dash_marker2 = 0; // not ok XML func
var dash_marker3 = 0; // in XML func
var liferFloat = 0.0; // lifer volume
var fig = 2; // type of 3D model

// Device online
var TOTAL_NET_DEVICES = 10;
var netDevicesNames = ["SWH", "HOM", "MED", "CMP", "PRN", "MGA", "UN1", "UN2", "LRN", "APC"];

// Timeline graphics
const MAX_CPU_LOAD_BUFFER = 16;
const MAX_GRAPH_BUFFER = 150;
const MAX_FORM_BUFFER = 90;
var bufferCpuLoad1 = [];
var bufferCpuLoad2 = [];
var bufferCpuLoad3 = [];
var bufferCpuLoad4 = [];
var bufferCpuLoad5 = [];
var bufferCpuLoad6 = [];

var bufferElectro1 = [];
var bufferElectro2 = [];
var bufferElectro3 = [];
var bufferElectro4 = [];
var bufferElectro5 = [];
var bufferElectro6 = [];
var bufferElectro7 = [];
var bufferElectro8 = [];
var bufferElectro9 = [];

var bufferLogo1 = [];

var modulName = ["RTC",       "ETR",            "SDC",      "SRV",          "MAJ",         "LRT",           "UPL",          "PIR",        "CNT",            "TMP",        "ELC",           "LED",        "KEY",        "PNG"];
var modulXml =  ["mRtc",      "mEthernet",      "mSd",      "mServer",      "mMajor",      "mLaurent",      "mUpload",      "mPirs",      "mContacts",      "mTemp",      "mElectro",      "mLeds",      "mKeys",      "mPing"];
var modulId =   ["modul-rtc", "modul-ethernet", "modul-sd", "modul-server", "modul-major", "modul-laurent", "modul-upload", "modul-pirs", "modul-contacts", "modul-temp", "modul-electro", "modul-leds", "modul-keys", "modul-ping"];

var contName = ["HOM",        "CLO"];
var contXml =  ["cont1",      "cont2"];
var contId =   ["dash-cont1", "dash-cont2"];

var pirName = ["STD",       "HAL",       "KID",       "KUH",       "PRH",       "CLO"];
var pirXml =  ["pir1",      "pir2",      "pir3",      "pir4",      "pir5",      "pir6"];
var pirId =   ["dash-pir1", "dash-pir2", "dash-pir3", "dash-pir4", "dash-pir5", "dash-pir6"];

var pinId = ["D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", "D8", "D9", "D10", "D11", "D12", "D13", "D14", "D15", "D16"];

var UiId = ["volt", "p1", "p2", "p3", "p4", "p5", "p6", "p7", "p8", "p9", "p10", "p11", "p12", "p13"];
var ui = [];

// Main function
function getDashData() {
  dash_marker2 = parseFloat("1.0");
  dash_marker3 = parseFloat("1.0");

  var request = new XMLHttpRequest();
  request.onreadystatechange = function() {
    if (this.readyState == 4) {
      if (this.status == 200) {
        if (this.responseXML != null) {

          dash_marker1 = parseFloat("1.0");
          dash_marker2 = parseFloat("0.0");

          // Moduls
          for (var i = 0; i < 14; i++) {
            try {
              var modulRes = this.responseXML.getElementsByTagName(modulXml[i])[0].childNodes[0].nodeValue;
            } catch (err) {
                modulRes = "-1";
              }
            try {
              document.getElementById(modulId[i]).innerHTML = modulName[i];
              document.getElementById(modulId[i]).style.background = modulBackground(modulRes);
              document.getElementById(modulId[i]).style.color = modulColor(modulRes);
            } catch (err) { }

            if (i == 13) {var modulPing = modulRes;}
          }

          // Contacts
          for (var i = 0; i < 2; i++) {
            try {
              var dcont = this.responseXML.getElementsByTagName(contXml[i])[0].childNodes[0].nodeValue;
            } catch (err) {
                dcont = "-1";
              }
            try {
              document.getElementById(contId[i]).innerHTML = contName[i];
              document.getElementById(contId[i]).style.background = contactBackground(dcont);
              document.getElementById(contId[i]).style.color = contactColor(dcont);
            } catch (err) { }
          }

          // PIR's
          for (var i = 0; i < 6; i++) {
            try {
              var dpir = this.responseXML.getElementsByTagName(pirXml[i])[0].childNodes[0].nodeValue;
            } catch (err) {
                dpir = "-1";
                //alert('Error' + err.name + ":" + err.message + "\n" + err.stack);
              }

            if (i == 2) {dpir = "-1";}
            try {
              document.getElementById(pirId[i]).innerHTML = pirName[i];
              document.getElementById(pirId[i]).style.background = pirBackground(dpir);
              document.getElementById(pirId[i]).style.color = pirColor(dpir);
            } catch (err) { }
          }

          // Lifer
          var MAX_LIFER = 7;
          var liferStr = '';
          try {
            var lifer = this.responseXML.getElementsByTagName('lifer')[0].childNodes[0].nodeValue;
          } catch (err) {
              lifer = 1;
            }
          liferFloat = parseFloat(lifer);

          for (var i = 0; i < MAX_LIFER; i++) {
            var ch = '·';
            if (i == liferFloat) {ch = '•';}
            liferStr += ch;
          }
          try {
            document.getElementById("lifer").innerHTML = liferStr;
          } catch (err) { }


          // Time & date
          try {
            var time = this.responseXML.getElementsByTagName('time')[0].childNodes[0].nodeValue;
          } catch (err) {
            time = '-';
            }
          try {
            document.getElementById("time").innerHTML = time;
            document.getElementById("time-hide").innerHTML = time;
          } catch (err) { }

          try {
            var day = this.responseXML.getElementsByTagName('day')[0].childNodes[0].nodeValue;
          } catch (err) {
              day = '-';
            }
          try {
            document.getElementById("day").innerHTML = day;
            document.getElementById("day-hide").innerHTML = day;
          } catch (err) {

            }

          try {
            var mon = this.responseXML.getElementsByTagName('month')[0].childNodes[0].nodeValue;
          } catch (err) {
              mon = '-';
            }
          try {
            monthStr = month(mon);
            document.getElementById("month").innerHTML = monthStr;
            document.getElementById("month-hide").innerHTML = monthStr;
          } catch (err) { }

          try {
            var wday = this.responseXML.getElementsByTagName('weekday')[0].childNodes[0].nodeValue;
          } catch (err) {
              wday = '-';
            }
          try {
            weekdayStr = weekday(wday);
            document.getElementById("week-day").innerHTML = weekdayStr;
            document.getElementById("week-day-hide").innerHTML = weekdayStr;
          } catch (err) { }

          // Temperature
          try {
            var tempSTR = this.responseXML.getElementsByTagName('tempSTR')[0].childNodes[0].nodeValue;
          } catch (err) {
              tempSTR = "0";
            }          
          
          // Voltage & power
          try {
            var dvolt = this.responseXML.getElementsByTagName('voltage')[0].childNodes[0].nodeValue;
          } catch (err) {
              dvolt = "0";
            }
          try {
            var tempSTR_ = Math.round(tempSTR, 1);
            document.getElementById("dash-voltage").innerHTML = tempSTR_ + "°";
            document.getElementById("dash-voltage-hide").innerHTML = tempSTR_ + "°";
          } catch (err) { }

          try {
            var pwr = this.responseXML.getElementsByTagName('power')[0].childNodes[0].nodeValue;
          } catch (err) {
              pwr = "0";
            }
          try {
            var power = Math.round(parseInt(pwr), 0);
            document.getElementById("dash-power").innerHTML = power;
            document.getElementById("dash-power-hide").innerHTML = power;
          } catch (err) { }

          // Uptime
          try {
            var uptm = this.responseXML.getElementsByTagName('uptime')[0].childNodes[0].nodeValue;
          } catch (err) {
              uptm = '-';
            }
          try {
            document.getElementById("uptime").innerHTML = uptm;
          } catch (err) { }

          // free RAM
          try {
            var freeRam = this.responseXML.getElementsByTagName('freeRAM')[0].childNodes[0].nodeValue;
          } catch (err) {
              freeRam = '-';
            }
          try {
            var freeRamPer = Math.round(freeRam / 462, 0); // MAX_FREE_MEM 46224 / 100 (dev ESP8266)
            document.getElementById("dash-free-ram").innerHTML = freeRam + ' / ' + freeRamPer + '%';
          } catch (err) { }

          // Cyclos / CPU load
          try {
            var cyclosDelay = this.responseXML.getElementsByTagName('cycDelay')[0].childNodes[0].nodeValue;
          } catch (err) {
              cyclosDelay = '-';
            }
          try {
            var cyclosInSec = this.responseXML.getElementsByTagName('cycInSec')[0].childNodes[0].nodeValue;
          } catch (err) {
              cyclosInSec = '-';
            }

          try {
            load('cpu-load',  1, freeRamPer, '', bufferCpuLoad1, '', 'mem', 'rgba(100, 160, 230, 1)', 'yellow', 'cyan');
          } catch (err) { }
          
          insertTick(16, bufferCpuLoad3);
          
          try {
            load('cpu-load3', 3, cyclosDelay, '', bufferCpuLoad4, '', 'cpu', 'rgba(100, 160, 230, 1)', 'cyan', 'lightblue');
          } catch (err) { }
          try {
            load('cpu-load4', 4, cyclosDelay, cyclosInSec, bufferCpuLoad5, bufferCpuLoad6, 'cpu', 'rgba(100, 160, 230, 1)', 'yellow', 'cyan');
          } catch (err) { }

          // Auth
          try {
            var auth = this.responseXML.getElementsByTagName('auth')[0].childNodes[0].nodeValue;
          } catch (err) {
              auth = "-";
            }
          var authText = '';
          if (auth == 1) {
            authText = 'AUT';
          } else {
              authText = 'FRE';
            }
          try {
            document.getElementById('auth').innerHTML = authText;
            document.getElementById('auth').style.background = authBackground(auth);
            document.getElementById('auth').style.color = authColor(auth);     
          } catch (err) { }
          try {
            document.getElementById('auth-footer').innerHTML = authText;
            document.getElementById('auth-footer').style.background = authBackground(auth);
            document.getElementById('auth-footer').style.color = authColor(auth);            
          } catch (err) { }
          
          // Mega partner
          try {
            var mega = this.responseXML.getElementsByTagName('mega')[0].childNodes[0].nodeValue;
          } catch (err) {mega = "-";}
          try {
            document.getElementById('mega').innerHTML = 'MGA';
            document.getElementById('mega').style.background = megaBackground(mega);
            document.getElementById('mega').style.color = megaColor(mega);     
          } catch (err) { } 
          
          // Ports page works
          if (currentPage == 'ports-page') {
            // HTTP request
            try {
              var httpr = this.responseXML.getElementsByTagName('httpReq')[0].childNodes[0].nodeValue;
            } catch (err) {
                httpr = '-'
              }
            try {
              document.getElementById("get-ports-request").innerHTML = httpr;
            } catch (err) { }

            try {
              // XML-req
              document.getElementById("get-ports-response").innerHTML = this.responseText;
            } catch (err) { }

            // Pins status
            for (var i = 0; i < 17; i++) {
              try {
                var pin = this.responseXML.getElementsByTagName(pinId[i])[0].childNodes[0].nodeValue;
              } catch (err) {
                  pin = "-1";
                }
              try {
                document.getElementById(pinId[i]).innerHTML = stateOnOff(pin);
                document.getElementById(pinId[i]).style.background = stateOnOffBackground(pin);
                document.getElementById(pinId[i]).style.color = stateOnOffColor(pin);
              } catch (err) { }
            }
              try {
                var A0 = this.responseXML.getElementsByTagName("A0")[0].childNodes[0].nodeValue;
              } catch (err) {
                   A0 = "-1";
                }
              try {
                document.getElementById("A0").innerHTML = A0;
              } catch (err) { }
          } // if (currentPage == 'ports-page')

          // Supply page works
          if (currentPage == 'supply-page') {
            // Electro
            try {
              document.getElementById("volt").innerHTML = dvoltage;
            } catch (err) { }
            try {
              document.getElementById("p1").innerHTML = power;
            } catch (err) { }

            try {
              graph('graph-voltage', 3, dvoltage, '', bufferElectro9, '', 'pwr', 'rgba(4, 169, 174, 1)', 'rgba(204,9,51, 1)', 'lightblue');
            } catch (err) { }
            try {
              graph('graph-power', 3, power, '', bufferElectro1, '', 'pwr', 'rgba(4, 169, 174, 1)', 'rgba(213,125,12, 1)', 'lightblue');
            } catch (err) { }

            // Period
            try {
              var period = this.responseXML.getElementsByTagName('period')[0].childNodes[0].nodeValue;
              period -= 100;
            } catch (err) {
                period = "-";
              }
            try {
              var frec = 1 / (period / 1000000);
              document.getElementById("freq").innerHTML = frec.toFixed(2);
            } catch (err) { }

            try {
              graph('graph-freq', 3, frec.toFixed(2), '', bufferElectro7, '', 'pwr', 'rgba(4, 169, 174, 1)', 'rgba(44,77,220, 1)', 'lightblue');
            } catch (err) { }
          } // if (currentPage == 'supply-page')

          // Electro page works
          if (currentPage == 'electro-page') {

            // Electro modul
            try {
              var modulElectro = this.responseXML.getElementsByTagName('modulElectro')[0].childNodes[0].nodeValue;
            } catch (err) {
                modulElectro = '-';
              }

            var modulElectroStatus = "";

            switch (modulElectro) {
              case "0":
                modulElectroStatus = "выключен";
                break;
              case "1":
                modulElectroStatus = "включен";
                break;
              default:
                modulElectroStatus = "отсутствует";
                try {
                  document.getElementById("button-electro").innerHTML = "-";
                  document.getElementById("button-electro").style.background = modulDisable;
                } catch (err) { }
              break;
            }
            try {
              document.getElementById("modul-electro").innerHTML = modulElectroStatus;
            } catch (err) { }

            // Electro
            for (var i = 0; i < 14; i++) {
              try {
                ui[i] = this.responseXML.getElementsByTagName(UiId[i])[0].childNodes[0].nodeValue;
                ui[i] = Math.round(parseInt(ui[i]), 0);
              } catch (err) {
                  ui[i] = "...";
                }
              try {
                document.getElementById(UiId[i]).innerHTML = ui[i];
              } catch (err) { }

            }
            try {
              graph('graph-test', 3, ui[1], '', bufferElectro1, '', 2, 'rgba(4, 169, 174, 1)', 'rgba(204,9,51, 1)', 'lightblue');
            } catch (err) { }
            try {
              graph('graph-cond', 3, ui[4], '', bufferElectro2, '', 2, 'rgba(4, 169, 174, 1)', 'rgba(213,125,12, 1)', 'lightblue');
            } catch (err) { }
            try {
              graph('graph-plita', 3, ui[2], '', bufferElectro3, '', 2, 'rgba(4, 169, 174, 1)', 'rgba(166,0,151, 1)', 'lightblue');
            } catch (err) { }
            try {
              graph('graph-str', 3, ui[3], '', bufferElectro4, '', 2, 'rgba(4, 169, 174, 1)', 'rgba(75,152,190, 1)', 'lightblue');
            } catch (err) { }
            try {
              device('device-plita', 3, ui[2], 'Плита',             200, 500, 900, 1500);
            } catch (err) { }
            try {
              device('device-str',   3, ui[3], 'Стиральная машина', 60, 300, 1500, 2000);
            } catch (err) { }
            try {
              device('device-cond',  3, ui[4], 'Кондиционер',       60, 100, 600, 1500);
            } catch (err) { }

            // draw bar
            //drawBar(p2, p3, p4, p6, p7, p8, p9, p10, p11, p12, p13);
          } // if (currentPage == 'electro-page')

        } // if (this.responseXML != null)
      } // if (this.status == 200)
    } // if (this.readyState == 4)
  } // request.onreadystatechange = function()

  dash_marker1 = parseFloat("0.0");

  request.open("GET", "request_dash" + currentPage + randomNoCache(), true);
  request.send(null);
  setTimeout('getDashData()', 3000);
  dash_marker3 = parseFloat("0.0");
} // getDashData()

function netLoad() {
  try {
    load('cpu-load2', 2, 0, 0, bufferCpuLoad2, bufferCpuLoad3, 'net', 'rgba(100, 160, 230, 1)', 'rgba(100, 160, 230, 1)', 'rgba(100, 160, 230, 1)');
  } catch (err) { }
}

/* end */